@@ -1,6 +1,6 @@
 /***************************************************************************
- *   Copyright (C) 2004, 2005 Thomas Nagy                                  *
- *   tnagy2^8@yahoo.fr                                                     *
+ *   Copyright (C) 2004, 2005, 2006 Thomas Nagy                            *
+ *   Thomas Nagy <tnagyemail-com@yahoo.fr>                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License version 2        *
@@ -230,7 +230,7 @@ void DCanvasLink::setPosWeb()
 	}
 	else
 	{
-		// when we dont know how to link, use straight lines
+		// when we do not know how to link, use straight lines
 		setPosLines();
 		m_candraw = false;
 		return;
@@ -271,92 +271,108 @@ void DCanvasLink::setPosThickWeb()
 	m_candraw = true;
 	int diffx=0, diffy=0;
 
-	if ( m_dest->x() > _C_ + m_orig->x() + m_orig->width() )
-	{
-		// parent is on the left
-		diffx = ((int) m_dest->x()) - ( ((int) m_orig->x()) + m_orig->width() );
+	QPoint points_o[4];
+	QPoint points_d[4];
+	// left
+	points_o[0] = QPoint( (int)(m_orig->x()), (int)(m_orig->y() + m_orig->height()/2) );
+	// top
+	points_o[1] = QPoint( (int)(m_orig->x() + m_orig->width()/2), (int)(m_orig->y()) );
+	// right
+	points_o[2] = QPoint( (int)(m_orig->x() + m_orig->width()), (int)(m_orig->y() + m_orig->height()/2) );
+	// bottom
+	points_o[3] = QPoint( (int)(m_orig->x() + m_orig->width()/2), (int)(m_orig->y() + m_orig->height()) );
 
-		m_pa[0]=QPoint( (int)(m_orig->x() + m_orig->width()), (int)(m_orig->y() + m_orig->height()/2));
-		m_pa[1]=QPoint( (int)(m_dest->x() - (1*diffx)/3    ), (int)(m_orig->y() + m_orig->height()/2));
-		m_pa[2]=QPoint( (int)(m_dest->x() - (2*diffx)/3    ), (int)(m_dest->y() + m_dest->height()/2));
-		m_pa[3]=QPoint( (int)(m_dest->x()                  ), (int)(m_dest->y() + m_dest->height()/2));
+	// left
+	points_d[0] = QPoint( (int)(m_dest->x()), (int)(m_dest->y() + m_dest->height()/2) );
+	// top
+	points_d[1] = QPoint( (int)(m_dest->x() + m_dest->width()/2), (int)(m_dest->y()) );
+	// right
+	points_d[2] = QPoint( (int)(m_dest->x() + m_dest->width()), (int)(m_dest->y() + m_dest->height()/2) );
+	// bottom
+	points_d[3] = QPoint( (int)(m_dest->x() + m_dest->width()/2), (int)(m_dest->y() + m_dest->height()) );
 
-		m_splineUp[0] = m_pa[0];
-		m_splineUp[1] = m_pa[1] + QPoint(0, s);
-		m_splineUp[2] = m_pa[2] + QPoint(0, s);
-		m_splineUp[3] = m_pa[3] + QPoint(0, s);
+	// figure out closest distance
+	double shortest = 0;
+	// compare each point from the first box to each point of the second box to see which pair is closer
+	for (int i = 0; i < 4; i++) {
+		for (int j = 0; j < 4; j++) {
+			double distance = sqrt(pow(points_o[i].x()-points_d[j].x(), 2) + pow(points_o[i].y()-points_d[j].y(), 2));
+			if (shortest == 0 || distance < shortest) {
+				shortest=distance;
 
-		m_splineDown[0] = m_pa[0];
-		m_splineDown[1] = m_pa[1] - QPoint(0, s);
-		m_splineDown[2] = m_pa[2] - QPoint(0, s);
-		m_splineDown[3] = m_pa[3] - QPoint(0, s);
-	}
-	else if ( m_dest->x() + m_dest->width() + _C_ < m_orig->x() )
-	{
-		// parent is on the right
-		diffx = ((int) m_orig->x()) - ( ((int) m_dest->x()) + m_dest->width() );
+				int x1 = (int)points_o[i].x();
+				int y1 = (int)points_o[i].y();
+				int x2 = (int)points_d[j].x();
+				int y2 = (int)points_d[j].y();
 
-		m_pa[0]=QPoint( (int)m_orig->x()                  , (int)(m_orig->y() + m_orig->height()/2));
-		m_pa[1]=QPoint( (int)m_orig->x() - (2*diffx)/3    , (int)(m_orig->y() + m_orig->height()/2));
-		m_pa[2]=QPoint( (int)m_orig->x() - (1*diffx)/3    , (int)(m_dest->y() + m_dest->height()/2));
-		m_pa[3]=QPoint( (int)m_dest->x() + m_dest->width(), (int)(m_dest->y() + m_dest->height()/2));
+				diffx = abs(x1 - x2);
+				diffy = abs(y1 - y2);
 
-		m_splineUp[0] = m_pa[0];
-		m_splineUp[1] = m_pa[1] + QPoint(0, s);
-		m_splineUp[2] = m_pa[2] + QPoint(0, s);
-		m_splineUp[3] = m_pa[3] + QPoint(0, s);
+				int xjump = 2 * diffx / 3;
+				int yjump = 2 * diffy / 3;
 
-		m_splineDown[0] = m_pa[0];
-		m_splineDown[1] = m_pa[1] - QPoint(0, s);
-		m_splineDown[2] = m_pa[2] - QPoint(0, s);
-		m_splineDown[3] = m_pa[3] - QPoint(0, s);
-	}
-	else if ( m_dest->y() + m_dest->height() + _C_ < m_orig->y() )
-	{
-		// parent is below
-		diffy = ((int) m_orig->y()) - ((int) m_dest->y()) - m_dest->height();
+				int xdir1 = 0;
+				int ydir1 = 0;
+				int xdir2 = 0;
+				int ydir2 = 0;
+				if (i == 0) {
+					// left side
+					xdir1 = -1;
+				} else if (i == 1) {
+					// top side
+					ydir1 = -1;
+				} else if (i == 2) {
+					// right side
+					xdir1 = 1;
+				} else if (i == 3) {
+					// bottom side
+					ydir1 = 1;
+				}
 
-		m_pa[0]=QPoint( (int)m_orig->x() + m_orig->width()/2, (int)(m_orig->y()));
-		m_pa[1]=QPoint( (int)m_orig->x() + m_orig->width()/2, (int)(m_orig->y() - (2*diffy)/3));
-		m_pa[2]=QPoint( (int)m_dest->x() + m_dest->width()/2, (int)(m_orig->y() - (1*diffy)/3));
-		m_pa[3]=QPoint( (int)m_dest->x() + m_dest->width()/2, (int)(m_dest->y() + m_dest->height()));
+				if (j == 0) {
+					// left side
+					xdir2 = -1;
+				} else if (j == 1) {
+					// top side
+					ydir2 = -1;
+				} else if (j == 2) {
+					// right side
+					xdir2 = 1;
+				} else if (j == 3) {
+					// bottom side
+					ydir2 = 1;
+				}
 
-		m_splineUp[0] = m_pa[0];
-		m_splineUp[1] = m_pa[1] + QPoint(s, 0);
-		m_splineUp[2] = m_pa[2] + QPoint(s, 0);
-		m_splineUp[3] = m_pa[3] + QPoint(s, 0);
+				m_pa[0]=points_o[i];
+				m_pa[1]=QPoint( x1 + xdir1*xjump , y1 + ydir1*yjump );
+				m_pa[2]=QPoint( x2 + xdir2*xjump , y2 + ydir2*yjump );
+				m_pa[3]=points_d[j];
 
-		m_splineDown[0] = m_pa[0];
-		m_splineDown[1] = m_pa[1] - QPoint(s, 0);
-		m_splineDown[2] = m_pa[2] - QPoint(s, 0);
-		m_splineDown[3] = m_pa[3] - QPoint(s, 0);
-	}
-	else if ( m_dest->y() > m_orig->y() + m_orig->height() + _C_ )
-	{
-		// parent is above
-		diffy = ((int) m_dest->y()) - ((int) m_orig->y()) - m_orig->height();
+				if (j == 0 || j == 2) {
+					// left or right side
+					m_splineUp[0] = m_pa[0];
+					m_splineUp[1] = m_pa[1] + QPoint(0, s/2);
+					m_splineUp[2] = m_pa[2] + QPoint(0, s);
+					m_splineUp[3] = m_pa[3] + QPoint(0, s);
 
-		m_pa[0]=QPoint( (int)m_orig->x() + m_orig->width()/2, (int)(m_orig->y() + m_orig->height()));
-		m_pa[1]=QPoint( (int)m_orig->x() + m_orig->width()/2, (int)(m_dest->y() - (1*diffy)/3));
-		m_pa[2]=QPoint( (int)m_dest->x() + m_dest->width()/2, (int)(m_dest->y() - (2*diffy)/3));
-		m_pa[3]=QPoint( (int)m_dest->x() + m_dest->width()/2, (int)(m_dest->y()));
+					m_splineDown[0] = m_pa[0];
+					m_splineDown[1] = m_pa[1] - QPoint(0, s/2);
+					m_splineDown[2] = m_pa[2] - QPoint(0, s);
+					m_splineDown[3] = m_pa[3] - QPoint(0, s);
+				} else {
+					// top or bottom side
+					m_splineUp[0] = m_pa[0];
+					m_splineUp[1] = m_pa[1] + QPoint(s/2, 0);
+					m_splineUp[2] = m_pa[2] + QPoint(s, 0);
+					m_splineUp[3] = m_pa[3] + QPoint(s, 0);
 
-		m_splineUp[0] = m_pa[0];
-		m_splineUp[1] = m_pa[1] + QPoint(s, 0);
-		m_splineUp[2] = m_pa[2] + QPoint(s, 0);
-		m_splineUp[3] = m_pa[3] + QPoint(s, 0);
-
-		m_splineDown[0] = m_pa[0];
-		m_splineDown[1] = m_pa[1] - QPoint(s, 0);
-		m_splineDown[2] = m_pa[2] - QPoint(s, 0);
-		m_splineDown[3] = m_pa[3] - QPoint(s, 0);
-	}
-	else
-	{
-		// when we dont know how to link, use straight lines
-		setPosLines();
-		m_candraw = false;
-		return;
+					m_splineDown[0] = m_pa[0];
+					m_splineDown[1] = m_pa[1] - QPoint(s/2, 0);
+					m_splineDown[2] = m_pa[2] - QPoint(s, 0);
+					m_splineDown[3] = m_pa[3] - QPoint(s, 0);
+				}
+			}
+		}
 	}
 
 	QPointArray bez1 = m_pa.cubicBezier();
