@@ -1,6 +1,6 @@
 /***************************************************************************
- *   Copyright (C) 2004, 2005 Thomas Nagy                                  *
- *   tnagy2^8@yahoo.fr                                                     *
+ *   Copyright (C) 2004, 2005, 2006 Thomas Nagy                            *
+ *   Thomas Nagy <tnagyemail-com@yahoo.fr>                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License version 2        *
@@ -14,6 +14,7 @@
 
 #include <kiconloader.h>
 #include <klocale.h>
+#include <kdebug.h>
 
 #include "settings.h"
 #include "DCanvasView.h"
@@ -25,7 +26,9 @@ DCanvasPopup::DCanvasPopup(QWidget *parent) : KPopupMenu(parent)
 	m_canvas = (DCanvasView*) parent;
 
 	// new object on the canvas / canvas manipulation
-	insertItem(i18n("New item"), e_item);
+	QString label_newitem = i18n("New Item");
+	if (m_canvas->itemsAreSelected()) label_newitem = i18n("New Child");
+	insertItem(label_newitem, e_item);
 
 	// edit actions
 	if ( m_canvas->itemsAreSelected() )
@@ -39,8 +42,6 @@ DCanvasPopup::DCanvasPopup(QWidget *parent) : KPopupMenu(parent)
 	// disconnect actions
 	KPopupMenu *disc_pop = new KPopupMenu(this, i18n("Disconnect"));
 
-	// disc_pop ~ disconnect popup :)
-
 	disc_pop->insertItem(i18n("Parent"), e_discon_parent);
 	disc_pop->insertItem(i18n("Object(s)"), e_discon_obj);
 	disc_pop->insertItem(i18n("Subtree"), e_discon_subtree);
@@ -49,45 +50,64 @@ DCanvasPopup::DCanvasPopup(QWidget *parent) : KPopupMenu(parent)
 	else if (m_canvas->selectedLink())
 		disc_pop->insertItem(i18n("Link"), e_discon_link);
 
+	if (!m_canvas->oneItemIsSelected()) disc_pop->setItemEnabled(e_discon_parent, false);
+
+	if (m_canvas->oneItemIsSelected())
+	{
+		insertItem(i18n("Select Subtree"), e_select_subtree);
+		insertSeparator();
+	}
+
 	insertItem( i18n("Disconnect"), disc_pop);
 
-	if (disc_pop)
-		connect(disc_pop, SIGNAL(activated(int)), this, SIGNAL(activated(int)));
+	if (disc_pop) connect(disc_pop, SIGNAL(activated(int)), this, SIGNAL(activated(int)));
 
 	if (m_canvas->oneItemIsSelected())
 	{
 		DDataItem *item = m_canvas->dataTree()->singleSelection();
-		if (item) setItemEnabled(e_discon_parent, item->Parent() != DItem::NOITEM );
-	}
-	setItemEnabled(e_discon_subtree, m_canvas->oneItemIsSelected());
-	setItemEnabled(e_discon_obj, m_canvas->itemsAreSelected());
+		if (item)
+		{
+			bool hasparent = (item->Parent() != DItem::NOITEM);
+			bool haschild  = (item->countChildren() > 0);
 
-	disc_pop->setEnabled( m_canvas->itemsAreSelected() || m_canvas->selectedRef() || m_canvas->selectedLink() );
+			setItemEnabled(e_discon_parent, hasparent);
+			setItemEnabled(e_discon_obj, hasparent && haschild);
+			setItemEnabled(e_discon_subtree, haschild);
+
+			disc_pop->setEnabled( haschild || hasparent );
+		}
+	}
+	else if (m_canvas->itemsAreSelected())
+	{
+		setItemEnabled(e_discon_subtree, m_canvas->oneItemIsSelected());
+		setItemEnabled(e_discon_obj, m_canvas->itemsAreSelected());
+		disc_pop->setEnabled( true );
+	}
+	else if (m_canvas->selectedRef() || m_canvas->selectedLink())
+	{
+		disc_pop->setEnabled( true );
+		setItemEnabled(e_discon_parent, false);
+		setItemEnabled(e_discon_obj, false);
+		setItemEnabled(e_discon_subtree, false);
+	}
 
 	insertSeparator();
 
-	// tydy actions
-
 	KPopupMenu *tidy_pop = new KPopupMenu(this, i18n("Tidy"));
 
-	tidy_pop->insertItem(i18n("Quick reorganization"), e_tidy_clean);
-	tidy_pop->insertItem(i18n("Smart reorganization (tm)"), e_tidy_all);
-	tidy_pop->insertItem(i18n("Unclutter the mindmap"), e_tidy_unclutter);
-
+	tidy_pop->insertItem(i18n("Quick Reorganization"), e_tidy_clean);
+	tidy_pop->insertItem(i18n("Smart Reorganization (tm)"), e_tidy_all);
+	tidy_pop->insertItem(i18n("Unclutter Mindmap"), e_tidy_unclutter);
 
 	insertItem( i18n("Tidy"), tidy_pop);
 	connect(tidy_pop, SIGNAL(activated(int)), this, SIGNAL(activated(int)));
 
 	tidy_pop->setEnabled(true);
-	//tidy_pop->setItemEnabled(e_tidy_unclutter, false);
 	insertSeparator();
 
-	//insertItem(i18n("Colors"), e_color);
-	//setItemEnabled(e_color, m_canvas->itemsAreSelected() );
-
 	KPopupMenu *col_pop = new KPopupMenu(this, i18n("Colors"));
 
-	col_pop->insertItem(i18n("Default color"), Settings::EnumColorMode::default_);
+	col_pop->insertItem(i18n("Default Color"), Settings::EnumColorMode::default_);
 	if (Settings::annotation(Settings::EnumColorMode::theme1_).length())
 		col_pop->insertItem(Settings::annotation(Settings::EnumColorMode::theme1_), Settings::EnumColorMode::theme1_);
 	else
@@ -129,10 +149,22 @@ DCanvasPopup::DCanvasPopup(QWidget *parent) : KPopupMenu(parent)
 
 	connect(col_pop, SIGNAL(activated(int)), this, SIGNAL(activated(int)));
 
-	insertItem( i18n("Colors"), col_pop);		
+	insertItem( i18n("Colors"), col_pop);
 	col_pop->setEnabled( m_canvas->itemsAreSelected() );
-	//setItemEnabled(col_pop, m_canvas->itemsAreSelected() );
 
-	insertItem(i18n("Font properties"), e_font);
+	insertItem(i18n("Select Font..."), e_font);
 	setItemEnabled(e_font, m_canvas->itemsAreSelected() );
+
+	KPopupMenu *align_pop = new KPopupMenu(this, i18n("Align and Distribute"));
+	align_pop->insertItem(i18n("Align Top"), e_align_top);
+	align_pop->insertItem(i18n("Align Bottom"), e_align_bottom);
+	align_pop->insertItem(i18n("Align Left"), e_align_left);
+	align_pop->insertItem(i18n("Align Right"), e_align_right);
+	align_pop->insertSeparator();
+	align_pop->insertItem(i18n("Distribute Horizontal"), e_distribute_horiz);
+	align_pop->insertItem(i18n("Distribute Vertical"), e_distribute_vert);
+
+	connect(align_pop, SIGNAL(activated(int)), this, SIGNAL(activated(int)));
+	insertItem(i18n("Align and Distribute"), align_pop);
+	align_pop->setEnabled( m_canvas->itemsAreSelected() and not m_canvas->oneItemIsSelected() );
 }
