@@ -1,6 +1,6 @@
 /***************************************************************************
- *   Copyright (C) 2004, 2005 Thomas Nagy                                  *
- *   tnagy2^8@yahoo.fr                                                     *
+ *   Copyright (C) 2004, 2005, 2006 Thomas Nagy                            *
+ *   Thomas Nagy <tnagyemail-com@yahoo.fr>                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License version 2        *
@@ -21,9 +21,10 @@
 #include <qmap.h>
 #include <qptrlist.h>
 #include <qpoint.h>
+#include <qstringlist.h>
 
 #include "settings.h"
-#include "aux.h"
+%:include "aux.h"
 #include "DBase.h"
 #include "DItem.h"
 #include "DDelta.h"
@@ -39,14 +40,6 @@ class DSpell;
 class DGuiView;
 
 class DDeltaCreate;
-
-/**
- * This class handles the necessary code for registering
- * and handling the mindmap items (data side)
- *
- * @short Main handler for mindmap item data
- * @author Thomas Nagy <tnagy2^8@yahoo.fr>
- */
 class DDataControl : public QObject, public DBase
 {
 	Q_OBJECT
@@ -56,11 +49,10 @@ class DDataControl : public QObject, public DBase
 	 * ie: freemind, knowit ..
 	 */
 	friend class DissertParser;
+	friend class DDeltaCreate;
 	friend class FFParser;
 	friend class DSpell;
 
-	//friend class DDeltaCreate;
-	
 	public:
 
 		/**
@@ -96,7 +88,7 @@ class DDataControl : public QObject, public DBase
 		int createItem(int parentid=DItem::NOITEM, int uniqueid=DItem::NOITEM);
 
 		/**
-		 * This method removes a mindmap item of the given id. 
+		 * This method removes a mindmap item of the given id.
 		 * it does nothing if the item does not exist
 		 */
 		void removeItem( int );
@@ -112,7 +104,7 @@ class DDataControl : public QObject, public DBase
 		void unlinkItems( int parent, int child );
 
 		/**
-		 * Remove the parent of a mindmap item 
+		 * Remove the parent of a mindmap item
 		 * this is a shortcut for unlinkItem(NOITEM, child)
 		 */
 		void setOrphan(int child);
@@ -126,7 +118,7 @@ class DDataControl : public QObject, public DBase
 		 * Unlink the item from its references
 		 */
 		void killRefs(int id);
-		
+
 		/**
 		 * Unlinks all children from a particular mindmap item recursively
 		 */
@@ -157,14 +149,14 @@ class DDataControl : public QObject, public DBase
 		/**
 		 * Load a mindmap from a file
 		 */
-		bool loadFromFile(const KURL &);
+		bool loadFromFile(const KURL &, bool import=0, bool nogui=0);
 
 		/**
 		 * Dump the data to a file
 		 */
 		void printTree(QTextStream&);
 
-		/** 
+		/**
 		 * Return to total amount of items
 		 */
 		int countItems();
@@ -217,16 +209,36 @@ class DDataControl : public QObject, public DBase
 		 */
 		void notifyItemModified(int id);
 
-		/** 
+		/**
+		 * Check if a project name has already be defined.
+		 */
+		bool hasProject() const;
+
+		/**
+		 * Set a new project name from a KURL object.
+		 * Extracts the filename part of the URL, without
+		 * path and @c .kdi extension.
+		 */
+		void setProject(const KURL&);
+
+		/**
 		 * The following variables represent per-document settings
 		 * They are public, but one has to be careful when setting them:
 		 * call updateSettings() when needed
 		 */
-		
+
+		/// The project's name
+		QString m_project;
+		/// The project's path
+		QString m_path;
 		/// Author first name
 		QString m_fname;
 		/// Author last name
 		QString m_sname;
+		/// Author e-mail address
+		QString m_email;
+		/// Author's company or institution
+		QString m_company;
 		/// preview size of the picture
 		int m_pixSize;
 		/// background color
@@ -243,16 +255,13 @@ class DDataControl : public QObject, public DBase
 		int m_showDirectionSize;
 		/// link style : lines, splines or thick splines
 		int m_linkstyle;
-		/// amount of times the generator was called
-		int m_generator_count;
 		/// last url used to generate a document
 		QString m_generator_lasturl;
 		/// last generator library used to generate a document
-		QString m_generator_lastgen;
-		
+		QStringList m_generator_lastgen;
+
 		/*
 		 * Use this to ask for adding or removing a reference
-		 * TODO : still unclear
 		 */
 		bool requestRefChange(int orig, int dest, bool add = true, bool check=true);
 
@@ -267,7 +276,7 @@ class DDataControl : public QObject, public DBase
 		/**
 		 * An item has changed position on the canvas view
 		 */
-		void registerMapPositionChange(int id, int oldx, int oldy, int newx, int newy);
+		void registerMapPositionChange(int id, DDataItem::Coord oldx, DDataItem::Coord oldy, DDataItem::Coord newx, DDataItem::Coord newy);
 
 		/**
 		 * Item color change
@@ -324,7 +333,11 @@ class DDataControl : public QObject, public DBase
 		void undoState(bool b);
 		void redoState(bool b);
 
-		
+		/**
+		 *  This signal is emitted to display a tip in the statusbar
+		 */
+		void tip(const QString &);
+
 	public slots:
 		/**
 		 *  Clear the current document
@@ -353,13 +366,15 @@ class DDataControl : public QObject, public DBase
 
 		void slotUndo();
 		void slotRedo();
-		
+
 	protected:
 		/*
 		 * Create a mindmap item with a particular id
 		 */
 		DDataItem* createItemWithId(int id);
 
+		void notifySpecial(DDataItem *item);
+
 	private:
 		/**
 		 *  Last item id used, mandatory for generating new items with unique ids
@@ -371,10 +386,10 @@ class DDataControl : public QObject, public DBase
 		 */
 		DDataItem* dataItem(int id) const;
 
-		/***
-		 * Memorise the last item selected (single selection)
+		/**
+		 *  Store the last item selected (single selection)
 		 */
-		DDataItem* m_itemselected;
+		DDataItem *m_itemselected;
 
 		/**
 		 *  Temporary directory for caching documents (pictures especially)
@@ -382,7 +397,7 @@ class DDataControl : public QObject, public DBase
 		KTempDir *m_fileholder;
 
 		/**
-		 * kdissert is spellcheck-enabled
+		 *  Spellcheck-enabled
 		 */
 		DSpell *m_spell;
 
@@ -394,7 +409,7 @@ class DDataControl : public QObject, public DBase
 		void addDelta(DDelta *);
 
 		bool m_undoredo_locked;
-		
+
 		QPtrStack<DDeltaList> m_undostack;
 		QPtrStack<DDeltaList> m_redostack;
 
