@@ -1,6 +1,6 @@
 /***************************************************************************
- *   Copyright (C) 2004, 2005 Thomas Nagy                                  *
- *   tnagy2^8@yahoo.fr                                                     *
+ *   Copyright (C) 2004, 2005, 2006 Thomas Nagy                            *
+ *   Thomas Nagy <tnagyemail-com@yahoo.fr>                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License version 2        *
@@ -26,7 +26,7 @@
 #include <kdebug.h>
 #include <klocale.h>
 
-#include "aux.h"
+%:include "aux.h"
 
 #include "DDataControl.h"
 #include "settings.h"
@@ -91,38 +91,48 @@ void DDataItem::removeChild(int id)
 	m_children.remove( id );
 }
 
-int DDataItem::countChildren() const
+unsigned int DDataItem::countChildren() const
 {
 	return m_children.count();
 }
 
-int DDataItem::childNum(int idx) const
+int DDataItem::childNum(unsigned int idx) const
 {
 	if (idx >= 0 && idx < countChildren()) return m_children[idx]; 
 	else return NOITEM;
 }
 
-int DDataItem::childIdx(int id) const
+unsigned int DDataItem::childIdx(unsigned int id) const
 {
 	return m_children.findIndex(id);
 }
 
-void DDataItem::setChildIdx(int id, int pos)
+void DDataItem::setChildIdx(unsigned int id, unsigned int pos)
 {
 	if (pos <0 || pos >= countChildren()) return;
 	if (! m_children.contains(id) ) return;
 
-	// intruder archtung ! :)
-	int intruderid = m_children[pos];
-	int newidxforintruder = m_children.findIndex(id);
+	// Remove the element temporarily
+	unsigned int cur_idx = m_children.findIndex(id);
+	QValueListIterator<int> cur_itr = m_children.at(cur_idx);
+	m_children.remove(cur_itr);
 
-	m_children[newidxforintruder] = intruderid;
-	m_children[pos]               = id;
+	// Re-insert the element
+	if (pos >= m_children.count())
+	{
+		// Since the list is now missing an element, we need to append
+		// rather than try to use an out-of-range iterator index.
+		m_children.append(id);
+	}
+	else
+	{
+		QValueListIterator<int> new_itr = m_children.at(pos);
+		m_children.insert(new_itr, id);
+	}
 }
 
-void DDataItem::setXY(int x, int y)
+void DDataItem::setXY(DDataItem::Coord x, DDataItem::Coord y)
 {
-	//kdDebug()<<"setting item id "<<Id()<<" to position "<<x<<" "<<y<<endl;
 	m_x = x;
 	m_y = y;
 }
@@ -179,8 +189,6 @@ void DDataItem::printSelf(QTextStream& s)
 	{
 		s<<" <flag>"<<QString::number( m_flags[i] )<<"</flag>\n";
 	}
-	
-	// that's all folks
 	s<<"</item>\n";
 }
 
@@ -222,7 +230,7 @@ void DDataItem::setColorScheme(int c)
 	m_colorscheme = c;
 
 	if (Parent() == NOITEM && m_manager->isUndoRedoLocked() && c!=Settings::EnumColorMode::default_)
-		KMessageBox::information( 0, 
+		KMessageBox::information( 0,
 			i18n("The item is a root item, so the color will only appear when it becomes linked to a parent mindmap item"),
 			0, "inform_user_when_root_item_and_color_changes");
 }
@@ -236,7 +244,7 @@ void DDataItem::setCustomColors(QColor c1, QColor c2, QColor c3)
 	m_outlinecolor = c2;
 	m_textcolor = c3;
 
-	if (Parent() == NOITEM && m_manager->isUndoRedoLocked()) KMessageBox::information( 0, 
+	if (Parent() == NOITEM && m_manager->isUndoRedoLocked()) KMessageBox::information( 0,
 			i18n("The item is a root item, so the color will only appear when it becomes linked to a parent mindmap item"),
 			0, "inform_user_when_root_item_and_color_changes");
 }
@@ -250,7 +258,7 @@ QColor DDataItem::fillColor()
 QColor DDataItem::realFillColor()
 {
 	if (m_colorscheme == Settings::EnumColorMode::custom_) return m_fillcolor;
-	return Settings::fillcolor( m_colorscheme ); 
+	return Settings::fillcolor( m_colorscheme );
 }
 
 QColor DDataItem::outlineColor()
@@ -269,10 +277,10 @@ QColor DDataItem::textColor()
 
 void DDataItem::clearPix()
 {
-	QString localfile = m_manager->getTmpDir()->absPath()+"/"+"pic-"+QString::number(Id());
+	QString localfile = m_manager->getTmpDir()->absPath()+'/'+"pic-"+QString::number(Id());
 	KIO::del(KURL(localfile+".png"), false, false);
 	KIO::del(KURL(localfile+".jpg"), false, false);
-	
+
 	m_picfilename = QString::null;
 	m_picurl = QString::null;
 	m_pix.resize(0, 0);
@@ -332,16 +340,18 @@ void DDataItem::loadPix(const QString & srcfilename)
 	m_pix.convertFromImage( img );
 
 	if (! m_pix.isNull())
-		m_pixtb.convertFromImage( 
+		m_pixtb.convertFromImage(
 				img.smoothScale( m_manager->m_pixSize, m_manager->m_pixSize, QImage::ScaleMin )  );
 }
 
 int DDataItem::countFamily() const
 {
 	int total = 1;
-	for (int i=0; i<countChildren(); i++)
+	for (unsigned int i=0; i<countChildren(); i++)
 	{
-		total += ((DDataItem*) m_manager->Item( childNum(i) ) )->countFamily();
+		DDataItem *item= (DDataItem*)m_manager->Item( childNum(i) );
+		if (item) total += item->countFamily();
+		else kdWarning()<<"DDataItem::countFamily bug"<<endl;
 	}
 	return total;
 }
