@@ -1,6 +1,6 @@
 /***************************************************************************
- *   Copyright (C) 2004, 2005 Thomas Nagy                                  *
- *   tnagy2^8@yahoo.fr                                                     *
+ *   Copyright (C) 2004, 2005, 2006 Thomas Nagy                            *
+ *   Thomas Nagy <tnagyemail-com@yahoo.fr>                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License version 2        *
@@ -21,10 +21,6 @@ class QString;
 class DDataControl;
 class DDataItem;
 class QTextStream;
-/**
- * @short Base class for the document generators
- * @author Thomas Nagy <tnagy2^8@yahoo.fr>
- */
 class DGenerator : public QObject
 {
 	Q_OBJECT
@@ -42,7 +38,11 @@ class DGenerator : public QObject
 		virtual bool generate(const QString &, DDataControl *);
 		virtual bool writeMaindoc(DDataItem*, const QString &);
 
+		virtual QWidget* confWidget();
+
 		bool copyfiles(const QString &);
+		bool generating;
+		bool cli;
 
 	protected:
 		/// transform usual text into latex
@@ -51,6 +51,9 @@ class DGenerator : public QObject
 		/// convert richtext to Tex commands
 		QString htmlToTex(const QString &);
 
+		/// convert richtext to a string that can be used for source code
+		QString protectCode(const QString &);
+
 		/// make the string commented for LaTeX
 		QString commentTex(const QString &);
 
