@@ -1,6 +1,6 @@
 /***************************************************************************
- *   Copyright (C) 2004, 2005 Thomas Nagy                                  *
- *   tnagy2^8@yahoo.fr                                                     *
+ *   Copyright (C) 2004, 2005, 2006 Thomas Nagy                            *
+ *   Thomas Nagy <tnagyemail-com@yahoo.fr>                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License version 2        *
@@ -28,8 +28,10 @@
 
 URLObject tmpobj;
 
-DissertParser::DissertParser(DDataControl*d) : QXmlDefaultHandler() 
+DissertParser::DissertParser(DDataControl*d, int idstart, bool importing) : QXmlDefaultHandler() 
 {
+	m_idstart = idstart;
+	m_importing = importing;
 	m_id = DItem::NOITEM;
 	m_inItem = false;
 
@@ -37,6 +39,13 @@ DissertParser::DissertParser(DDataControl*d) : QXmlDefaultHandler()
 	m_datacontrol = d;
 }
 
+int DissertParser::realID(int val)
+{
+	if (val==DItem::NOITEM)
+		return val;
+	return m_idstart+val;
+}
+
 bool DissertParser::startDocument()
 {
 	return true;
@@ -50,14 +59,18 @@ bool DissertParser::startElement( const QString&, const QString&, const QString&
 	}
 	else if (qName == "ref")
 	{
-		int iddest = attrs.value("dest").toInt();
+		int iddest = realID( attrs.value("dest").toInt() );
 		//QString txt = attrs.value(1);
 		m_datacontrol->requestRefChange( m_id, iddest, true, false);
 	}
-	else if (qName == "meta")
+	else if (qName == "meta" && !m_importing)
 	{
+		m_datacontrol->m_project = attrs.value("project");
+		m_datacontrol->m_path = attrs.value("path");
 		m_datacontrol->m_fname = attrs.value("fname");
 		m_datacontrol->m_sname = attrs.value("sname");
+		m_datacontrol->m_email = attrs.value("email");
+		m_datacontrol->m_company = attrs.value("company");
 
 		m_datacontrol->m_pixSize = attrs.value("pixsize").toInt();
 		m_datacontrol->m_col_background.setNamedColor( attrs.value("colbackground") );
@@ -68,9 +81,8 @@ bool DissertParser::startElement( const QString&, const QString&, const QString&
 		m_datacontrol->m_picturesOnCanvas = (bool) attrs.value("picturesoncanvas").toInt();
 
 		m_datacontrol->m_generator_lasturl = attrs.value("generator_lasturl");
-		m_datacontrol->m_generator_lastgen = attrs.value("generator_lastgen");
-		m_datacontrol->m_generator_count = attrs.value("generator_count").toInt();
-		
+		m_datacontrol->m_generator_lastgen = QStringList::split(",", attrs.value("generator_lastgen"));
+
 		m_datacontrol->m_showDirectionSize = attrs.value("showdirectionsize").toInt();
 		m_datacontrol->m_linkstyle = attrs.value("linkstyle").toInt();
 	}
@@ -94,10 +106,10 @@ bool DissertParser::endElement( const QString&, const QString&, const QString& q
 {
 	if (qName == "id")
 	{
-		m_id = m_str.toInt();
+		m_id = realID( m_str.toInt() );
 		m_datacontrol->createItemWithId( m_id );
 	}
-	else if (qName == "version")
+	else if (qName == "version" && !m_importing)
 	{
 		m_docversion = m_str.toInt();
 	}
@@ -107,19 +119,21 @@ bool DissertParser::endElement( const QString&, const QString&, const QString& q
 
 		if (qName == "xpos")
 		{
-			item->setXY( m_str.toInt(), item->y());
+			item->setXY( m_str.toDouble(), item->y());
+			if (item->x() < 1) item->setXY( 1, item->y());
 		}
 		else if (qName == "ypos")
 		{
-			item->setXY( item->x(), m_str.toInt());
+			item->setXY( item->x(), m_str.toDouble());
+			if (item->y() < 1) item->setXY( 1, item->x());
 		}
 		else if (qName == "parent")
 		{
-			item->setParent(m_str.toInt());
+			item->setParent( realID( m_str.toInt() ) );
 		}
 		else if (qName == "child")
 		{
-			item->addChild(m_str.toInt());
+			item->addChild( realID(m_str.toInt()) );
 		}
 		else if (qName == "defaultfont")
 		{
@@ -226,7 +240,7 @@ bool DissertParser::endElement( const QString&, const QString&, const QString& q
 	return true;
 }
 
-bool DissertParser::characters( const QString& s)
+bool DissertParser::characters(const QString& s)
 {
 	m_str = s;
 	return true;
