@@ -1,6 +1,6 @@
 /***************************************************************************
- *   Copyright (C) 2004, 2005 Thomas Nagy                                  *
- *   tnagy2^8@yahoo.fr                                                     *
+ *   Copyright (C) 2004, 2005, 2006 Thomas Nagy                            *
+ *   Thomas Nagy <tnagyemail-com@yahoo.fr>                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License version 2        *
@@ -17,24 +17,17 @@
 
 #include <qxml.h>
 
-//#include "DDataItem.h"
-
 class QString;
 class QStringList;
 class DItem;
 class DDataControl;
-/**
- * This class handles the necessary code for 
- * importing kdissert (.kdi) and knowit (.kno) files
- *
- * @short kdissert and knowit import tools
- * @author Thomas Nagy <tnagy2^8@yahoo.fr>
- * @version 0.3.1
- */
 class DissertParser : public QXmlDefaultHandler
 {
 	public:
-		DissertParser(DDataControl*d);
+		/**
+		 * Constructor
+		 */
+		DissertParser(DDataControl *d, int idstart=0, bool importing=false);
 
 		bool startDocument();
 		bool startElement( const QString&, const QString&, const QString&, const QXmlAttributes& );
@@ -45,7 +38,9 @@ class DissertParser : public QXmlDefaultHandler
 	private:
 
 		bool m_inItem;
+		bool m_importing;
 
+		int m_idstart;
 		int m_id;
 		int m_docversion;
 
@@ -53,6 +48,8 @@ class DissertParser : public QXmlDefaultHandler
 		QString m_tmpstr;
 		//URLObject m_obj
 
+		int realID(int);
+		
 		DDataControl* m_datacontrol;
 };
 
