@@ -1,6 +1,6 @@
 /***************************************************************************
- *   Copyright (C) 2004, 2005 Thomas Nagy                                  *
- *   tnagy2^8@yahoo.fr                                                     *
+ *   Copyright (C) 2004, 2005, 2006 Thomas Nagy                            *
+ *   Thomas Nagy <tnagyemail-com@yahoo.fr>                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License version 2        *
@@ -21,6 +21,5 @@
 #define ABS(x) ((x)>0?(x):-(x))
 #define MAX(x, y) ((x)>(y)?(x):(y))
 #define MIN(x, y) ((x)>(y)?(y):(x))
-#define _STATE_OFFSET_ 4000
 
 #endif // _AUXKDISSERT_H
