@@ -1,34 +1,27 @@
 /***************************************************************************
- *   Copyright (C) 2004, 2005 Thomas Nagy                                  *
- *   tnagy2^8@yahoo.fr                                                     *
+ *   Copyright (C) 2004, 2005, 2006 Thomas Nagy                            *
+ *   Thomas Nagy <tnagyemail-com@yahoo.fr>                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
+ *   it under the terms of the GNU General Public License version 2        *
+ *   as published by the Free Software Foundation (see COPYING)            *
  *                                                                         *
  *   This program is distributed in the hope that it will be useful,       *
  *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
  *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
  *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
  ***************************************************************************/
 
 #ifndef _DGUI_ITEM_H
 #define _DGUI_ITEM_H
 
-#include "../datastruct/DItem.h"
-#include "../datastruct/DDataItem.h"
+#include "datastruct/DItem.h"
+#include "datastruct/DDataItem.h"
 
 class DGuiView;
 /**
  * @short Base class for item views
  * @author Thomas Nagy <tnagy2^8@yahoo.fr>
- * @version 0.3.1
  */
 class DGuiItem : public DItem
 {
@@ -37,10 +30,15 @@ class DGuiItem : public DItem
 		~DGuiItem();
 
 	protected:
+		/**
+		 * Return the data item associated
+		 */
 		DDataItem* data() const;
-		const DDataItem* data(int) const;
+
+		/**
+		 * Return the parent view
+		 */
 		DGuiView* m_parent;
 };
 
 #endif // _DGUI_ITEM_H
-
