@@ -1,6 +1,6 @@
 /***************************************************************************
- *   Copyright (C) 2004, 2005 Thomas Nagy                                  *
- *   tnagy2^8@yahoo.fr                                                     *
+ *   Copyright (C) 2004, 2005, 2006 Thomas Nagy                            *
+ *   Thomas Nagy <tnagyemail-com@yahoo.fr>                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License version 2        *
@@ -27,6 +27,7 @@ class KRadioAction;
 class DGuiView;
 class DCanvasView;
 class DTreeListView;
+class TreeListViewFrame;
 class DDataControl;
 class DDataItem;
 
@@ -64,7 +65,7 @@ class KDissertPart : public KParts::ReadWritePart
 
 		static KAboutData *createAboutData();
 
-		inline DTreeListView *treeview() {return m_treelistview;}
+		inline TreeListViewFrame *treeview() { return m_treelistframe; }
 
 		/*
 		 * Tell the views that the settings have changed
@@ -74,6 +75,9 @@ class KDissertPart : public KParts::ReadWritePart
 
 		QString m_caption;
 
+		// use with care
+		DCanvasView* getCanvas();
+
 	protected:
 		/**
 		 * This must be implemented by each part
@@ -127,9 +131,21 @@ class KDissertPart : public KParts::ReadWritePart
 		 */
 		void updateColorActionsState();
 
+		/**
+		 * This is called, when the list of objects selected on the map
+		 * has changed to update movement actions
+		 */
+		void updateMovementActionsState();
+
 		void setUndoState(bool st);
 		void setRedoState(bool st);
 
+		void emitStatusBarMessage(const QString &);
+
+		void setActionType(int);
+
+		void importData();
+
 	private slots:
 
 		void setItemChanged(int);
@@ -156,6 +172,7 @@ class KDissertPart : public KParts::ReadWritePart
 		void slotFileOpen();
 		void slotFileSave();
 		void slotFileSaveAs();
+		void slotPrintMap();
 		void slotRefresh();
 
 		/*
@@ -168,7 +185,7 @@ class KDissertPart : public KParts::ReadWritePart
 		 * This covers the 'preview document' feature
 		 */
 		void regenerateDocument();
-		
+
 		/*
 		 * This method is used to take a snapshot of the mindmap
 		 * view as a png file
@@ -179,12 +196,8 @@ class KDissertPart : public KParts::ReadWritePart
 		void focusIn();
 		void focusOut();
 
-		void focus50();
-		void focus75();
-		void focus100();
-		void focus125();
-		void focus150();
-		void focus200();
+		void setZoom(const QString &);
+		void zoomChange(int);
 
 	private:
 
@@ -192,6 +205,7 @@ class KDissertPart : public KParts::ReadWritePart
 		DCanvasView* m_canvasview;
 		/// This object holds the tree view
 		DTreeListView* m_treelistview;
+		TreeListViewFrame* m_treelistframe;
 		/// This object handles the mindmap data
 		DDataControl* m_data;
 
@@ -199,17 +213,28 @@ class KDissertPart : public KParts::ReadWritePart
 		KAction* m_saveAction;
 
 		void checkReExportState();
-		
-		void setZoom(float zoom);
+
 		void updateColorActions();
 		int m_lastid;
 
-		KToggleAction *m_warning, *m_good, *m_idea, *m_work, 
-			      *m_clarify, *m_question, *m_trash, *m_meeting, *m_trouble;
-		KRadioAction *m_zoom50, *m_zoom75, *m_zoom100, *m_zoom125, *m_zoom150, *m_zoom200;
+		KToggleAction *m_warning, *m_good, *m_idea, *m_work, *m_clarify, *m_question, *m_trash, *m_meeting, *m_trouble;
+
+		typedef struct zoomLevel {
+			float value;
+			KRadioAction* action;
+		} zoomLevel;
+
+		QMap<QString,zoomLevel> zoomLevels;
+
 		KAction *m_undo, *m_redo;
 		KRadioAction *m_default, *m_theme1, *m_theme2, *m_theme3, *m_theme4, *m_theme5, *m_theme6, *m_custom;
 		KAction *m_regenerate;
+
+		KAction *m_moveup, *m_movedown, *m_moveleft, *m_moveright;
+		KAction *m_aligntop, *m_alignbottom, *m_alignleft, *m_alignright;
+		KAction *m_distributehoriz, *m_distributevert;
+
+		KRadioAction *m_select, *m_link, *m_sort, *m_scroll;
 };
 
 #endif // _KDISSERTPART_H_
