@@ -1,6 +1,6 @@
 /***************************************************************************
- *   Copyright (C) 2004, 2005 Thomas Nagy                                  *
- *   tnagy2^8@yahoo.fr                                                     *
+ *   Copyright (C) 2004, 2005, 2006 Thomas Nagy                            *
+ *   Thomas Nagy <tnagyemail-com@yahoo.fr>                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License version 2        *
@@ -33,8 +33,17 @@ BoxURL::BoxURL(QWidget *parent) : KListView(parent)
 {
 	m_item = NULL;
 	m_popup = NULL;
+	setDragEnabled(true);
 	setAcceptDrops(true);
 
+	setItemsMovable(true);
+        setDropVisualizer(true);
+
+	setSelectionModeExt( KListView::Single );
+
+	connect( this, SIGNAL( moved( QListViewItem*, QListViewItem*, QListViewItem* ) ),
+			this, SLOT( applyMoved( QListViewItem*, QListViewItem* , QListViewItem* ) ) );
+
 	connect(this, SIGNAL( contextMenu(KListView*, QListViewItem*, const QPoint&) ),
 			this, SLOT( popupmenu(KListView*, QListViewItem*, const QPoint&) ) );
 
@@ -42,11 +51,19 @@ BoxURL::BoxURL(QWidget *parent) : KListView(parent)
 			this, SLOT( launchSelectedURL() ) );
 
 	connect(this, SIGNAL( datachanged() ), this, SLOT( updateItem() ) );
-	
+
 	header()->hide();
 
 	addColumn(i18n("Links"));
 	setResizeMode(KListView::AllColumns);
+
+	setSorting(-1);
+}
+
+void BoxURL::applyMoved( QListViewItem* current, QListViewItem*, QListViewItem* afternow )
+{
+	updateItem();
+	updateFromItem();
 }
 
 void BoxURL::dragEnterEvent(QDragEnterEvent* event)
@@ -78,7 +95,7 @@ void BoxURL::setCurrentItem(DDataItem* item)
 	else
 	{
 		setEnabled(true);
-		if ( m_item != item ) 
+		if ( m_item != item )
 		{
 			m_item = item;
 			updateFromItem();
@@ -95,7 +112,7 @@ void BoxURL::updateItem()
 	while (it.current())
 	{
 		BoxURLItem* item = (BoxURLItem*) (*it);
-		m_item->m_urllist.append( item->m_object );
+		m_item->m_urllist.prepend( item->m_object );
 		++it;
 	}
 }
@@ -128,7 +145,7 @@ void BoxURL::requestChangeURL()
 {
 	BoxURLItem* item = (BoxURLItem*) selectedItem();
 	if (!item) return;
-	
+
 	urldlg *dlg = new urldlg(this, item->m_object);
 	if (KDialogBase::Accepted == dlg->exec())
 	{
@@ -140,7 +157,7 @@ void BoxURL::requestChangeURL()
 void BoxURL::addItem(URLObject& obj)
 {
 	if (!obj.m_caption.length() && !obj.m_url.length()) return;
-	
+
 	BoxURLItem* lstitem = new BoxURLItem(this);
 	lstitem->m_object = obj;
 	lstitem->updateCaption();
@@ -202,7 +219,7 @@ void BoxURL::launchURL(const QString& url)
 void BoxURLItem::updateCaption()
 {
 	if (!m_object.m_caption.length()) setText(0, m_object.m_url);
-	else setText(0, m_object.m_caption+" ["+m_object.m_url+"]");
+	else setText(0, m_object.m_caption+" ["+m_object.m_url+']');
 }
 
 #include "BoxURL.moc"
