@@ -1,6 +1,6 @@
 /***************************************************************************
- *   Copyright (C) 2004, 2005 Thomas Nagy                                  *
- *   tnagy2^8@yahoo.fr                                                     *
+ *   Copyright (C) 2004, 2005, 2006 Thomas Nagy                            *
+ *   Thomas Nagy <tnagyemail-com@yahoo.fr>                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License version 2        *
@@ -33,12 +33,13 @@ class BoxURL : public KListView
 		void setCurrentItem(DDataItem*);
 		void requestAddURL();
 		void requestChangeURL();
-		
+
 		void addSingleURL( const QString & url );
 		void updateFromItem();
 
 		void launchSelectedURL();
-		
+		void applyMoved( QListViewItem *, QListViewItem * afterFirst, QListViewItem * afterNow );
+
 	signals:
 		void datachanged();
 
