@@ -1,6 +1,6 @@
 /***************************************************************************
- *   Copyright (C) 2004, 2005 Thomas Nagy                                  *
- *   tnagy2^8@yahoo.fr                                                     *
+ *   Copyright (C) 2004, 2005, 2006 Thomas Nagy                            *
+ *   Thomas Nagy <tnagyemail-com@yahoo.fr>                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License version 2        *
@@ -37,22 +37,22 @@
 #include <kdeversion.h>
 #include <kmenubar.h>
 #include <kkeydialog.h>
-#include <kmessagebox.h>
 #include <ktabwidget.h>
 #include <kedittoolbar.h>
 #include <kstdaccel.h>
 #include <kaction.h>
 #include <kstdaction.h>
+#include <kedittoolbar.h>
 
 #include "settings.h"
 #include "prefs-base.h"
-#include "DTreeListView.h"
 #include "KDissertPart.h"
 #include "KDissertView.h"
 #include "TextProperties.h"
 #include "MiscProperties.h"
 #include "KDissert.h"
 
+
 KDissert::KDissert(KMdi::MdiMode mode)
 	: KMdiMainFrm( 0, "KDissert", mode )
 {
@@ -89,13 +89,11 @@ KDissert::KDissert(KMdi::MdiMode mode)
 
 	connect( this, SIGNAL( viewActivated( KMdiChildView * ) ), this, SLOT( currentChanged( KMdiChildView * ) ) );
 
-	KMdiToolViewAccessor *acc=NULL;
-	
 	m_miscproperties = new MiscProperties(this, "misc_infos");
 	m_miscproperties->setIcon( SmallIcon("attach") );
 	m_miscproperties->setCaption( i18n("Attachments") );
 	m_misctoolview = addToolWindow( m_miscproperties, KDockWidget::DockBottom, getMainDockWidget(), 20 );
-	
+
 	m_textproperties = new TextProperties(this, "properties");
 	m_textproperties->setIcon( SmallIcon("pencil") );
 	m_textproperties->setCaption( i18n("Item Text") );
@@ -104,8 +102,8 @@ KDissert::KDissert(KMdi::MdiMode mode)
 	m_treeviewstack = new QWidgetStack(this, "treeview_stack");
 	m_treeviewstack->setIcon( SmallIcon("kdissert") );
 	m_treeviewstack->setCaption( i18n("Tree View") );
-	m_frame = new QFrame(m_treeviewstack);
-	m_treeviewstack->addWidget( m_frame );
+	m_lframe = new QFrame(m_treeviewstack);
+	m_treeviewstack->addWidget( m_lframe );
 	m_listtoolview = addToolWindow( m_treeviewstack, KDockWidget::DockLeft, getMainDockWidget(), 30 );
 
 #if KDE_IS_VERSION(3, 3, 0)
@@ -126,7 +124,7 @@ KDissert::KDissert(KMdi::MdiMode mode)
 	if (cfg->readNumEntry("kdissert_main_dock_settings", 0) == 1) manager()->readConfig(cfg);
 	cfg->writeEntry("kdissert_main_dock_settings", 1);
 	delete cfg;
-	
+
 	//changeCaption(QString::null);
 	showTipOnStart();
 }
@@ -149,7 +147,7 @@ void KDissert::setupActions()
 	m_openRecentAction->setWhatsThis( i18n("Opens recently opened file.") );
 	m_openRecentAction->loadEntries( kapp->config(), "RecentFiles" );
 
-	KStdAction::tipOfDay( this, SLOT( showTip() ), actionCollection() 
+	KStdAction::tipOfDay( this, SLOT( showTip() ), actionCollection()
 			)->setWhatsThis(i18n("This shows useful tips on the use of this application."));
 
 	KStdAction::close(this, SLOT(slotFileClose()), actionCollection());
@@ -159,32 +157,16 @@ void KDissert::setupActions()
 	m_statusbarAction = KStdAction::showStatusbar(this, SLOT(optionsShowStatusbar()), actionCollection());
 
 	KStdAction::keyBindings(this, SLOT(optionsConfigureKeys()), actionCollection());
+	KStdAction::configureToolbars(this, SLOT(optionsConfigureToolbars()), actionCollection());
 	KStdAction::preferences(this, SLOT(optionsPreferences()), actionCollection());
 
 
-	new KAction( i18n("Focus on the text panel"), "F2", this, SLOT(slotFocusOnTPanel()), actionCollection(), "kdissert_focustpanel");
-	new KAction( i18n("Focus on the map"), "F3", this, SLOT(slotFocusOnMap()), actionCollection(), "kdissert_focusmap");
-	//    new KAction( i18n("Focus on the attachement panel"), "F3", this, SLOT(slotFocusOnAPanel()), actionCollection(), "kdissert_focusapanel");
-
-	// TODO : Volunteers ? anyone ?
-	//KAction* action = KStdAction::configureToolbars(this, 
-	//         SLOT(optionsConfigureToolbars()), actionCollection());
-/*
-	new KAction(i18n("&Add link..."), 0, this,
-			SLOT(slotLinkAdd()), actionCollection(), "link_add");
-	new KAction(i18n("&Remove link"), 0, this,
-			SLOT(slotLinkRemove()), actionCollection(), "link_remove");
-	new KAction(i18n("Open link"), 0, this,
-			SLOT(slotLinkOpen()), actionCollection(), "link_open");
-	new KAction(i18n("&Modify link..."), 0, this,
-			SLOT(slotLinkModify()), actionCollection(), "link_modify");
-	new KAction(i18n("&Copy link location"), 0, this,
-			SLOT(slotLinkCopy()), actionCollection(), "link_copy");
-*/
+	new KAction( i18n("Focus on Text Panel"), "F2", this, SLOT(slotFocusOnTPanel()), actionCollection(), "kdissert_focustpanel");
+	new KAction( i18n("Focus on Map"), "F3", this, SLOT(slotFocusOnMap()), actionCollection(), "kdissert_focusmap");
 	createGUI( NULL );
 }
 
-void KDissert::showTip() 
+void KDissert::showTip()
 {
 	KTipDialog::showTip(this,QString::null,true);
 }
@@ -202,11 +184,11 @@ void KDissert::slotFileNew()
 	connect(view->part(), SIGNAL(itemSelected(DDataItem*, bool)), m_textproperties, SLOT(setCurrentItem(DDataItem*, bool)));
 	connect(view->part(), SIGNAL(itemChanged(int)), m_textproperties, SLOT(itemChanged(int)) );
 	connect(view->part(), SIGNAL(itemSelected(DDataItem*, bool)), m_miscproperties, SLOT(setCurrentItem(DDataItem*, bool)));
+	connect(view, SIGNAL(newCaption(const QString &)), this, SLOT(setCaption(const QString &)));
 
 	addWindow( view );
 
-	// add the tree view to the widget stack
-	m_treeviewstack->addWidget( view->part()->treeview() );
+	m_treeviewstack->addWidget( view->m_lwidget );
 	m_views += view;
 
 	connect(view->part(), SIGNAL(accessed(const KURL&)), this, SLOT(slotFileOpened(const KURL&)) );
@@ -218,16 +200,15 @@ void KDissert::slotFileOpened(const KURL & url)
 {
 	m_openRecentAction->addURL(url);
 	m_openRecentAction->saveEntries( kapp->config(), "RecentFiles" );
-	//statusBar()->message(i18n("The project was saved")+" "+url.prettyURL(), 5000);
 }
 
 void KDissert::slotFileOpen()
 {
 	KURL url = KFileDialog::getOpenURL(QString::null,
-			i18n("*.kdi|kdissert project (*.kdi)") +"\n"+
-			i18n("*.mm|Freemind files (*.mm)") +"\n"+
-			i18n("*.kno|Knowit files (*.kno)") ,
-			NULL, i18n("Open a mindmap project"));
+			i18n("*.kdi|kdissert Project (*.kdi)") +'\n'+
+			i18n("*.mm|Freemind Files (*.mm)") +'\n'+
+			i18n("*.kno|Knowit Files (*.kno)") ,
+			NULL, i18n("Open Mindmap Project"));
 
 	if (url.isEmpty())
 		return;
@@ -257,11 +238,12 @@ void KDissert::openURL(const KURL & url)
 	connect(view->part(), SIGNAL(itemChanged(int)), m_textproperties, SLOT(itemChanged(int)) );
 	connect(view->part(), SIGNAL(itemSelected(DDataItem*, bool)), m_miscproperties, SLOT(setCurrentItem(DDataItem*, bool)));
 	connect(view->part(), SIGNAL(accessed(const KURL&)), this, SLOT(slotFileOpened(const KURL&)) );
+	connect(view, SIGNAL(newCaption(const QString &)), this, SLOT(setCaption(const QString &)));
 
 	addWindow( view );
 
 	// add the tree view to the widget stack
-	m_treeviewstack->addWidget( view->part()->treeview() );
+	m_treeviewstack->addWidget( view->m_lwidget );
 	m_views += view;
 
 	view->part()->openURL(url);
@@ -274,8 +256,7 @@ void KDissert::currentChanged( KMdiChildView *current )
 	if (!current)
 	{
 		m_manager->setActivePart(NULL);
-		setCaption("kdissert");
-		m_treeviewstack->raiseWidget( m_frame );
+		m_treeviewstack->raiseWidget( m_lframe );
 		return;
 	}
 
@@ -285,13 +266,7 @@ void KDissert::currentChanged( KMdiChildView *current )
 		KDissertView *view = (KDissertView*) current;
 		view->updateCaption();
 		m_manager->setActivePart( view->part() );
-
-		/*	if (view->part()->url().isValid())
-			{
-			m_openRecentAction->addURL(view->part()->url());
-			}*/
-
-		m_treeviewstack->raiseWidget( view->part()->treeview() );
+		m_treeviewstack->raiseWidget( view->m_lwidget );
 	}
 }
 
@@ -302,10 +277,6 @@ void KDissert::slotFileClose()
 
 bool KDissert::requestClose(KMdiChildView* v)
 {
-	//    kdWarning()<<"closing view"<<v<<endl;
-	//    if (view == NULL)
-	//	return;
-
 	if (v == NULL)
 	{
 		if ( m_views.count() == 1)
@@ -315,12 +286,11 @@ bool KDissert::requestClose(KMdiChildView* v)
 			{
 				m_manager->removePart( view->part() );
 
-				m_treeviewstack->removeWidget( view->part()->treeview() );
-				m_treeviewstack->raiseWidget( m_frame );
+				m_treeviewstack->removeWidget( view->m_lwidget );
+				m_treeviewstack->raiseWidget( m_lframe );
 
 				closeWindow( view );
 				m_views.clear();
-				setCaption("kdissert");
 				return true;
 			}
 			return false;
@@ -328,17 +298,14 @@ bool KDissert::requestClose(KMdiChildView* v)
 		return true;
 	}
 
-	// TODO : warning : we are using only KDissertView parts for the moment
-	// what will happen if we load other kind of parts ? (ita)
 	KDissertView *view = (KDissertView*) v;
 	if ( m_views.contains( view ) )
 	{
-		m_views.remove( view );
 		if ( view->part()->queryClose() )
 		{
+			m_views.remove( view );
 			m_manager->removePart( view->part() );
-			m_treeviewstack->removeWidget( view->part()->treeview() );
-
+			m_treeviewstack->removeWidget( view->m_lwidget );
 			closeWindow( view );
 			return true;
 		}
@@ -383,17 +350,13 @@ void KDissert::optionsConfigureKeys()
 
 void KDissert::optionsConfigureToolbars()
 {
-	//saveMainWindowSettings(KGlobal::config(), autoSaveGroup());
+	KEditToolbar dlg(guiFactory());
+	if (dlg.exec())
+	{
+		createGUI( m_manager->activePart() );
+	}
 }
 
-/*void KDissert::newToolbarConfig()
-  {
-// this slot is called when user clicks "Ok" or "Apply" in the toolbar editor.
-// recreate our GUI, and re-apply the settings (e.g. "text under icons", etc.)
-createGUI();
-applyMainWindowSettings(KGlobal::config(), autoSaveGroup());
-}*/
-
 void KDissert::optionsPreferences()
 {
 	// The preference dialog is derived from prefs-base.ui which is subclassed into Prefs
@@ -401,7 +364,7 @@ void KDissert::optionsPreferences()
 	// compare the names of the widgets in the .ui file 
 	// to the names of the variables in the .kcfg file
 	if (KConfigDialog::showDialog("settings"))
-		return;	
+		return;
 
 	KConfigDialog *dialog = new KConfigDialog(this, "settings", Settings::self(), KDialogBase::Swallow);
 	dialog->addPage(new Prefs_base(), i18n("General"), "package_settings");
@@ -411,20 +374,13 @@ void KDissert::optionsPreferences()
 
 void KDissert::settingsChanged()
 {
-	// tell the truth to our documents
 	QValueList<KDissertView*>::iterator it  = m_views.begin();
 	QValueList<KDissertView*>::iterator end = m_views.end();
 	for (; it != end; ++it)
 	{
 		KDissertView *view = *it;
 		view->part()->settingsChanged();
-	} 
-}
-
-void KDissert::changeStatusbar(const QString& text)
-{
-	// display the text on the statusbar
-	statusBar()->message(text, 2000);
+	}
 }
 
 void KDissert::dragEnterEvent(QDragEnterEvent *event)
@@ -436,13 +392,11 @@ void KDissert::dragEnterEvent(QDragEnterEvent *event)
 void KDissert::dropEvent(QDropEvent *event)
 {
 	KURL::List urls;
-
 	// see if we can decode a URI.. if not, just ignore it
 	if (KURLDrag::decode(event, urls) && !urls.isEmpty())
 	{
 		// okay, we have a URI.. process it
 		const KURL &url = urls.first();
-
 		// load in the file
 		openURL(url);
 	}
@@ -468,13 +422,11 @@ bool KDissert::queryClose()
 	{
 		// now close all views
 		KDissertView *view = *it;
-
 		m_manager->removePart( view->part() );
 		closeWindow( view );
 	}
 
 	m_openRecentAction->saveEntries( kapp->config(), "RecentFiles" );
-
 	return true;
 }
 
@@ -493,7 +445,8 @@ void KDissert::slotFocusOnMap()
 
 void KDissert::slotSetStatusBarText(const QString & mes)
 {
-	statusBar()->message(mes, 5000); 
+	statusBar()->message(mes, 5000);
 }
 
 #include "KDissert.moc"
+
