@@ -1,6 +1,6 @@
 /***************************************************************************
- *   Copyright (C) 2004, 2005 Thomas Nagy                                  *
- *   tnagy2^8@yahoo.fr                                                     *
+ *   Copyright (C) 2004, 2005, 2006 Thomas Nagy                            *
+ *   Thomas Nagy <tnagyemail-com@yahoo.fr>                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License version 2        *
@@ -28,7 +28,6 @@ class QWidgetStack;
 class KDissertView;
 class TextProperties;
 class MiscProperties;
-class Systray;
 
 /**
  * This class serves as the main window for kdissert.  It handles the
@@ -75,7 +74,6 @@ class KDissert : public KMdiMainFrm
 	void optionsPreferences();
 	//void newToolbarConfig();
 
-	void changeStatusbar(const QString& text);
 	//void changeCaption(const QString& text);
 
 	void currentChanged( KMdiChildView *current );
@@ -88,7 +86,7 @@ class KDissert : public KMdiMainFrm
 	void setupActions();
 
 	QValueList<KDissertView*> m_views;
-	
+
 	KToggleAction *m_toolbarAction;
 	KToggleAction *m_statusbarAction;
 	KRecentFilesAction *m_openRecentAction;
@@ -96,14 +94,15 @@ class KDissert : public KMdiMainFrm
 	KParts::PartManager *m_manager;
 
 	QWidgetStack *m_treeviewstack;
+	QWidgetStack *m_navigationstack;
 	TextProperties *m_textproperties;
 	MiscProperties *m_miscproperties;
 
-	// TODO
-	//QWidgetStack *m_navigationstack;
-	QFrame *m_frame;
+	QFrame *m_lframe;
+	QFrame *m_cframe;
 	KMdiToolViewAccessor* m_textpropertiestoolview;
 	KMdiToolViewAccessor* m_listtoolview;
+	KMdiToolViewAccessor* m_navtoolview;
 	KMdiToolViewAccessor* m_misctoolview;
 };
 
