@@ -1,6 +1,6 @@
 /***************************************************************************
- *   Copyright (C) 2004, 2005 Thomas Nagy                                  *
- *   tnagy2^8@yahoo.fr                                                     *
+ *   Copyright (C) 2004, 2005, 2006 Thomas Nagy                            *
+ *   Thomas Nagy <tnagyemail-com@yahoo.fr>                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License version 2        *
@@ -27,20 +27,26 @@ class KDissertPart;
  * @author Thomas Nagy <tnagy2^8@yahoo.fr>
  * @version 0.3.3
  */
-class KDissertView : public KMdiChildView 
+class KDissertView : public KMdiChildView
 {
-    Q_OBJECT
-    public:
-	KDissertView( QWidget *parentWidget=0L, const char *name=0L );
-	virtual ~KDissertView();
+	Q_OBJECT
+	public:
+		KDissertView( QWidget *parentWidget=0L, const char *name=0L );
+		virtual ~KDissertView();
 
-	KDissertPart *part();
+		KDissertPart *part();
+		QWidget *m_lwidget;
+		QWidget *m_cwidget;
 
-    private:
-	KDissertPart *m_part;
-    
-    public slots:
-	void updateCaption();
+	private:
+		KDissertPart *m_part;
+
+		public slots:
+			void updateCaption();
+
+signals:
+		void newCaption(const QString &);
 };
 
 #endif // _KDISSERTVIEW_H
+
