@@ -1,6 +1,6 @@
 /***************************************************************************
- *   Copyright (C) 2005 Thomas Nagy                                        *
- *   tnagy2^8@yahoo.fr                                                     *
+ *   Copyright (C) 2004, 2005, 2006 Thomas Nagy                            *
+ *   Thomas Nagy <tnagyemail-com@yahoo.fr>                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License version 2        *
@@ -29,7 +29,7 @@
 #include "BoxURL.h"
 #include "TextProperties.h"
 
-TextProperties::TextProperties(QWidget *parent, const char *name) : 
+TextProperties::TextProperties(QWidget *parent, const char *name):
 	TextProperties_base(parent, name)
 {
 	m_lastitem = NULL;
@@ -64,24 +64,21 @@ void TextProperties::setCurrentItem(DDataItem* item, bool force)
 	disconnect(textedit, SIGNAL(textChanged()), this, SLOT(updateItem()));
 	disconnect(m_boxurl, SIGNAL(datachanged()), this, SLOT(updateItem()) );
 
-	if (item != m_lastitem || force)
-	{
-		summaryedit->clear();
-		textedit->clear();
-	}
-
-	m_lastitem = item;
 	m_boxurl->setCurrentItem(item);
 
 	if (item)
 	{
-		summaryedit->setText(item->m_summary);
-		textedit->setText(item->m_text);
 		m_boxurl->setEnabled(true);
 		linksbox->setEnabled(true);
 
 		summaryedit->setEnabled(true);
 		textedit->setReadOnly(false);
+
+		if (item != m_lastitem || force)
+		{
+			summaryedit->setText(item->m_summary);
+			textedit->setText(item->m_text);
+		}
 	}
 	else
 	{
@@ -93,8 +90,16 @@ void TextProperties::setCurrentItem(DDataItem* item, bool force)
 		boldbt->setDown(false);
 		italicbt->setDown(false);
 		underlinebt->setDown(false);
+
+		if (item != m_lastitem || force)
+		{
+			summaryedit->clear();
+			textedit->clear();
+		}
 	}
 
+	m_lastitem = item;
+
 	connect(m_boxurl, SIGNAL(datachanged()), this, SLOT(updateItem()) );
 	connect(summaryedit, SIGNAL(textChanged(const QString&)), this, SLOT(updateItem()));
 	connect(textedit, SIGNAL(textChanged()), this, SLOT(updateItem()));
@@ -102,7 +107,10 @@ void TextProperties::setCurrentItem(DDataItem* item, bool force)
 
 void TextProperties::itemChanged(int id)
 {
-	if (!m_lastitem) return;
+	if (!m_lastitem)
+	{
+		return;
+	}
 
 	if (m_lastitem->Id() == id)
 		if (summaryedit->text() != m_lastitem->m_summary)
