@@ -1,6 +1,6 @@
 /***************************************************************************
- *   Copyright (C) 2004, 2005 Thomas Nagy                                  *
- *   tnagy2^8@yahoo.fr                                                     *
+ *   Copyright (C) 2004, 2005, 2006 Thomas Nagy                            *
+ *   Thomas Nagy <tnagyemail-com@yahoo.fr>                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License version 2        *
@@ -27,7 +27,7 @@ DTreeListPopup::DTreeListPopup(QWidget *parent) : KPopupMenu(parent)
 	m_lstview = (DTreeListView*) parent;
 
 	// new object
-	insertItem(i18n("New item"), e_item);
+	insertItem(i18n("New Item"), e_item);
 
 	// edit actions
 	if ( m_lstview->selectedItem() )
@@ -68,7 +68,7 @@ DTreeListPopup::DTreeListPopup(QWidget *parent) : KPopupMenu(parent)
 	// properties actions
 	KPopupMenu *col_pop = new KPopupMenu(this, i18n("Colors"));
 
-	col_pop->insertItem(i18n("Default color"), Settings::EnumColorMode::default_);
+	col_pop->insertItem(i18n("Default Color"), Settings::EnumColorMode::default_);
 	if (Settings::annotation(Settings::EnumColorMode::theme1_).length())
 		col_pop->insertItem(Settings::annotation(Settings::EnumColorMode::theme1_), Settings::EnumColorMode::theme1_);
 	else
@@ -110,9 +110,9 @@ DTreeListPopup::DTreeListPopup(QWidget *parent) : KPopupMenu(parent)
 
 	connect(col_pop, SIGNAL(activated(int)), this, SIGNAL(activated(int)));
 
-	insertItem( i18n("Colors"), col_pop);		
+	insertItem( i18n("Colors"), col_pop);
 	col_pop->setEnabled( m_lstview->selectedItem() );
 
-	insertItem(i18n("Properties..."), e_properties);
+	insertItem(i18n("Properties"), e_properties);
 	setItemEnabled(e_properties, m_lstview->selectedItem() );
 }
