@@ -1,6 +1,6 @@
 /***************************************************************************
- *   Copyright (C) 2004, 2005 Thomas Nagy                                  *
- *   tnagy2^8@yahoo.fr                                                     *
+ *   Copyright (C) 2004, 2005, 2006 Thomas Nagy                            *
+ *   Thomas Nagy <tnagyemail-com@yahoo.fr>                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License version 2        *
@@ -265,7 +265,7 @@ const QString kdissOOOdoc::identifikation()
 
 const QString kdissOOOdoc::fullName()
 {
-	return i18n("OpenOffice.org Writer");
+	return i18n("Text document");
 }
 
 const QString kdissOOOdoc::group()
@@ -288,8 +288,8 @@ void kdissOOOdoc::outputData(DDataItem* item, QTextStream & s, int level)
 	// links
 	for (unsigned int i=0; i<item->m_urllist.count(); i++)
 	{
-		QString url = item->m_urllist[i].m_url;
-		QString caption = item->m_urllist[i].m_caption;
+		QString url = DDataItem::protectXML(item->m_urllist[i].m_url);
+		QString caption = DDataItem::protectXML(item->m_urllist[i].m_caption);
 
 		if (!caption.length()) caption = url;
 
@@ -396,7 +396,7 @@ void kdissOOOdoc::writeItem(DDataItem* item, QTextStream & s, int level)
 		
 		if (item->countChildren() > 0)
 		{
-			for (int i = 0; i<item->countChildren(); i++)
+			for (unsigned int i = 0; i<item->countChildren(); i++)
 				writeItem((DDataItem*) m_data->Item(item->childNum(i)), s, level+1);
 		}
 	}
@@ -428,7 +428,7 @@ void kdissOOOdoc::writeItem(DDataItem* item, QTextStream & s, int level)
 		// And now the children
 		if (item->countChildren() > 0)
 		{
-			for (int i = 0; i<item->countChildren(); i++)
+			for (unsigned int i = 0; i<item->countChildren(); i++)
 				writeItem((DDataItem*) m_data->Item(item->childNum(i)), s, level+1);
 		}
 	}
@@ -468,7 +468,7 @@ void kdissOOOdoc::writeItemPic(DDataControl * data, DDataItem *item, QTextStream
 		//item->m_pix.save(path+"/Pictures/"+"pic-"+QString::number(data->idNum(i))+".png", "PNG");
 	}
 
-	for (int i=0; i<item->countChildren(); i++)
+	for (unsigned int i=0; i<item->countChildren(); i++)
 	{
 		writeItemPic( data, (DDataItem*) data->Item(item->childNum(i)), m );
 	}
@@ -545,8 +545,17 @@ bool kdissOOOdoc::writeMaindoc(DDataItem *root, const QString & path)
 
 	//v<<"<text:author-name text:fixed=\"false\">";
 	v<<DDataItem::protectXML(m_data->m_fname)<<" "<<DDataItem::protectXML(m_data->m_sname);
+        if (!m_data->m_email.isEmpty())
+        {
+          v<<"<text:tab-stop/><text:tab-stop/>"<<DDataItem::protectXML(m_data->m_email);
+        }
 	//v<<"</text:author-name>";
-	v<<"</text:p></style:header><style:footer><text:p text:style-name=\"Footer\"><text:date style:data-style-name=\"N37\" text:date-value=\"\" text:fixed=\"false\"></text:date><text:tab-stop/><text:page-number text:select-page=\"current\">1</text:page-number>/<text:page-count>3</text:page-count></text:p></style:footer></style:master-page></office:master-styles></office:document-styles>";
+	v<<"</text:p></style:header><style:footer><text:p text:style-name=\"Footer\"><text:date style:data-style-name=\"N37\" text:date-value=\"\" text:fixed=\"false\"></text:date><text:tab-stop/><text:page-number text:select-page=\"current\">1</text:page-number>/<text:page-count>3</text:page-count>";
+        if (!m_data->m_company.isEmpty())
+        {
+          v<<"<text:tab-stop/>"<<DDataItem::protectXML(m_data->m_company);
+        }
+        v<<"</text:p></style:footer></style:master-page></office:master-styles></office:document-styles>";
 	stylefile.close();
 
 	// TODO process the meta-data section
@@ -597,13 +606,27 @@ bool kdissOOOdoc::writeMaindoc(DDataItem *root, const QString & path)
 
 	// remove the (now useless) temporary files
 	// do not show the progressdialog
-	KIO::del(KURL(path+"/content.xml"), false, false );
-	KIO::del(KURL(path+"/meta.xml"), false, false );
-	KIO::del(KURL(path+"/mimetype"), false, false );
-	KIO::del(KURL(path+"/settings.xml"), false, false );
-	KIO::del(KURL(path+"/styles.xml"), false, false );
-	KIO::del(KURL(path+"/META-INF"), false, false );
-	KIO::del(KURL(path+"/Pictures"), false, false );
+
+	if (cli)
+	{
+		KIO::del(KURL(path+"/META-INF"), false, false );
+		KIO::del(KURL(path+"/Pictures"), false, false );
+		QFile(path+"/mimetype").remove();
+		QFile(path+"/content.xml").remove();
+		QFile(path+"/meta.xml").remove();
+		QFile(path+"/settings.xml").remove();
+		QFile(path+"/styles.xml").remove();
+	}
+	else
+	{
+		KIO::del(KURL(path+"/content.xml"), false, false );
+		KIO::del(KURL(path+"/meta.xml"), false, false );
+		KIO::del(KURL(path+"/mimetype"), false, false );
+		KIO::del(KURL(path+"/settings.xml"), false, false );
+		KIO::del(KURL(path+"/styles.xml"), false, false );
+		KIO::del(KURL(path+"/META-INF"), false, false );
+		KIO::del(KURL(path+"/Pictures"), false, false );
+	}
 
 	notifyDocGenerated( path+"/newdoc.sxw" );
 
