@@ -55,7 +55,7 @@ class kdissOOOimpress : public DGenerator
 	void outputData(DDataItem* item, QTextStream & s, int level);
 
 	/// write recursively the pics of a tree to the manifest file
-	void kdissOOOimpress::writeItemPic(DDataControl*, DDataItem *item, QTextStream & m);
+	void writeItemPic(DDataControl*, DDataItem *item, QTextStream & m);
 
 	static int m_slidecount;
 };
