@@ -1,6 +1,6 @@
 /***************************************************************************
- *   Copyright (C) 2004, 2005 Thomas Nagy                                  *
- *   tnagy2^8@yahoo.fr                                                     *
+ *   Copyright (C) 2004, 2005, 2006 Thomas Nagy                            *
+ *   Thomas Nagy <tnagyemail-com@yahoo.fr>                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License version 2        *
@@ -42,7 +42,7 @@ const QString kdisspdflatexarticle::identifikation()
 
 const QString kdisspdflatexarticle::fullName()
 {
-	return i18n("LaTeX article");
+	return i18n("LaTeX Article");
 }
 
 const QString kdisspdflatexarticle::group()
@@ -70,7 +70,7 @@ void kdisspdflatexarticle::outputPixParagraph(DDataItem* item, QTextStream & s)
 	// TODO: check the maximum width of the picture
 	s<<"\\begin{figure}[htbp]\n";
 	s<<"\\begin{center}\n";
-	s<<"\\includegraphics[width=10cm]{pics/pic-"<<QString::number(item->Id())<<"}\n";
+	s<<"\\includegraphics[width=14cm]{pics/pic-"<<QString::number(item->Id())<<"}\n";
 	s<<"\\caption{\\footnotesize{"<<protectTex(item->m_piccaption)<<"}}\n";
 	s<<"%"<<item->m_picurl<<"\n";
 	s<<"\\end{center}\n";
@@ -97,7 +97,12 @@ void kdisspdflatexarticle::outputLinks(DDataItem* item, QTextStream & s)
 void kdisspdflatexarticle::outputComment(DDataItem* item, QTextStream & s)
 {
 	if (item->m_comment.length()>0)
-		s<<"\\footnote{"<<htmlToTex(item->m_comment)<<"}\n";
+	{
+		if (Settings::commentTex())
+			s<<item->m_comment<<"\n";
+		else
+			s<<"\\footnote{"<<htmlToTex(item->m_comment)<<"}\n";
+	}
 }
 
 void kdisspdflatexarticle::outputData(DDataItem* item, QTextStream & s)
@@ -121,7 +126,10 @@ void kdisspdflatexarticle::writeItem(DDataItem* item, QTextStream & s, int level
 
 			// comment this text since it is out of the body text
 			s<<"\n"<<commentTex( htmlToTex(item->m_text) )<<"\n";
-			s<<commentTex(item->m_comment)<<"\n";
+			if (Settings::commentTex())
+				s<<item->m_comment<<"\n";
+			else
+				s<<commentTex(item->m_comment)<<"\n";
 			break;
 		case 1:
 			s<<"\\section{"<<protectTex(item->m_summary)<<"}\n\n";
@@ -141,7 +149,7 @@ void kdisspdflatexarticle::writeItem(DDataItem* item, QTextStream & s, int level
 			break;
 	}	
 
-	for (int i = 0; i<item->countChildren(); i++)
+	for (unsigned int i = 0; i<item->countChildren(); i++)
 	{
 		writeItem((DDataItem*) m_data->Item(item->childNum(i)), s, level+1);
 	}
@@ -174,7 +182,14 @@ bool kdisspdflatexarticle::writeMaindoc(DDataItem *root, const QString & path)
 	u<<"\\lhead{}\n";
 	u<<"\\chead{}\n";
 	u<<"\\rhead{}\n";
-	u<<"\\lfoot{"<<protectTex(m_data->m_fname)<<" "<<protectTex(m_data->m_sname)<<"}\n";
+        if (!m_data->m_company.isEmpty())
+        {
+          u<<"\\lfoot{"<<protectTex(m_data->m_company)<<"}\n";
+        }
+        else
+        {
+          u<<"\\lfoot{"<<protectTex(m_data->m_fname)<<" "<<protectTex(m_data->m_sname)<<"}\n";
+        }
 	u<<"\\cfoot{\\thepage/\\pageref{LastPage}}\n";
 	u<<"\\rfoot{ \\today } % -> \\rfoot{\\number\\month/\\number\\day/\\number\\year} \n";
 	u<<"\\pagestyle{fancyplain}\n";
@@ -182,9 +197,16 @@ bool kdisspdflatexarticle::writeMaindoc(DDataItem *root, const QString & path)
 
 	// make a nice title for the first page
 	u<<"\\title{"<<protectTex(root->m_summary)<<"}\n";
-	u<<"\\date{}\n";
-	u<<"\\author{"<<protectTex(m_data->m_fname)<<" "<<protectTex(m_data->m_sname)<<"}\n";
-
+	u<<"\\date{\\today}\n";
+        if (!m_data->m_email.isEmpty())
+        {
+          u<<"\\author{"<<protectTex(m_data->m_fname)<<" "<<protectTex(m_data->m_sname)<<" \\\\ \\texttt{"<<protectTex(m_data->m_email)<<"}}\n";
+        }
+        else
+        {
+          u<<"\\author{"<<protectTex(m_data->m_fname)<<" "<<protectTex(m_data->m_sname)<<"}\n";
+        }
+        
 	// standard headers
 	u<<"\n";
 	u<<"\\begin{document}\n";
